@@ -6,7 +6,7 @@ from pathlib import Path
 import pytest
 from packaging.version import parse as parse_version
 
-from PIL import Image, features
+from PIL import GifImagePlugin, Image, WebPImagePlugin, features
 
 from .helper import (
     assert_image_equal,
@@ -22,10 +22,12 @@ def test_n_frames() -> None:
     """Ensure that WebP format sets n_frames and is_animated attributes correctly."""
 
     with Image.open("Tests/images/hopper.webp") as im:
+        assert isinstance(im, WebPImagePlugin.WebPImageFile)
         assert im.n_frames == 1
         assert not im.is_animated
 
     with Image.open("Tests/images/iss634.webp") as im:
+        assert isinstance(im, WebPImagePlugin.WebPImageFile)
         assert im.n_frames == 42
         assert im.is_animated
 
@@ -37,11 +39,13 @@ def test_write_animation_L(tmp_path: Path) -> None:
     """
 
     with Image.open("Tests/images/iss634.gif") as orig:
+        assert isinstance(orig, GifImagePlugin.GifImageFile)
         assert orig.n_frames > 1
 
-        temp_file = str(tmp_path / "temp.webp")
+        temp_file = tmp_path / "temp.webp"
         orig.save(temp_file, save_all=True)
         with Image.open(temp_file) as im:
+            assert isinstance(im, WebPImagePlugin.WebPImageFile)
             assert im.n_frames == orig.n_frames
 
             # Compare first and last frames to the original animated GIF
@@ -67,8 +71,9 @@ def test_write_animation_RGB(tmp_path: Path) -> None:
     are visually similar to the originals.
     """
 
-    def check(temp_file: str) -> None:
+    def check(temp_file: Path) -> None:
         with Image.open(temp_file) as im:
+            assert isinstance(im, WebPImagePlugin.WebPImageFile)
             assert im.n_frames == 2
 
             # Compare first frame to original
@@ -87,7 +92,7 @@ def test_write_animation_RGB(tmp_path: Path) -> None:
 
     with Image.open("Tests/images/anim_frame1.webp") as frame1:
         with Image.open("Tests/images/anim_frame2.webp") as frame2:
-            temp_file1 = str(tmp_path / "temp.webp")
+            temp_file1 = tmp_path / "temp.webp"
             frame1.copy().save(
                 temp_file1, save_all=True, append_images=[frame2], lossless=True
             )
@@ -99,7 +104,7 @@ def test_write_animation_RGB(tmp_path: Path) -> None:
             ) -> Generator[Image.Image, None, None]:
                 yield from ims
 
-            temp_file2 = str(tmp_path / "temp_generator.webp")
+            temp_file2 = tmp_path / "temp_generator.webp"
             frame1.copy().save(
                 temp_file2,
                 save_all=True,
@@ -116,7 +121,7 @@ def test_timestamp_and_duration(tmp_path: Path) -> None:
     """
 
     durations = [0, 10, 20, 30, 40]
-    temp_file = str(tmp_path / "temp.webp")
+    temp_file = tmp_path / "temp.webp"
     with Image.open("Tests/images/anim_frame1.webp") as frame1:
         with Image.open("Tests/images/anim_frame2.webp") as frame2:
             frame1.save(
@@ -127,6 +132,7 @@ def test_timestamp_and_duration(tmp_path: Path) -> None:
             )
 
     with Image.open(temp_file) as im:
+        assert isinstance(im, WebPImagePlugin.WebPImageFile)
         assert im.n_frames == 5
         assert im.is_animated
 
@@ -141,7 +147,7 @@ def test_timestamp_and_duration(tmp_path: Path) -> None:
 
 
 def test_float_duration(tmp_path: Path) -> None:
-    temp_file = str(tmp_path / "temp.webp")
+    temp_file = tmp_path / "temp.webp"
     with Image.open("Tests/images/iss634.apng") as im:
         assert im.info["duration"] == 70.0
 
@@ -159,7 +165,7 @@ def test_seeking(tmp_path: Path) -> None:
     """
 
     dur = 33
-    temp_file = str(tmp_path / "temp.webp")
+    temp_file = tmp_path / "temp.webp"
     with Image.open("Tests/images/anim_frame1.webp") as frame1:
         with Image.open("Tests/images/anim_frame2.webp") as frame2:
             frame1.save(
@@ -170,6 +176,7 @@ def test_seeking(tmp_path: Path) -> None:
             )
 
     with Image.open(temp_file) as im:
+        assert isinstance(im, WebPImagePlugin.WebPImageFile)
         assert im.n_frames == 5
         assert im.is_animated
 
@@ -196,10 +203,10 @@ def test_alpha_quality(tmp_path: Path) -> None:
     with Image.open("Tests/images/transparent.png") as im:
         first_frame = Image.new("L", im.size)
 
-        out = str(tmp_path / "temp.webp")
+        out = tmp_path / "temp.webp"
         first_frame.save(out, save_all=True, append_images=[im])
 
-        out_quality = str(tmp_path / "quality.webp")
+        out_quality = tmp_path / "quality.webp"
         first_frame.save(
             out_quality, save_all=True, append_images=[im], alpha_quality=50
         )
