@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Any
+from typing import Any
 
 import pytest
 from packaging.version import parse as parse_version
@@ -13,6 +13,7 @@ numpy = pytest.importorskip("numpy", reason="NumPy not installed")
 
 im = hopper().resize((128, 100))
 
+TYPE_CHECKING = False
 if TYPE_CHECKING:
     import numpy.typing as npt
 
@@ -47,7 +48,7 @@ def test_toarray() -> None:
             with pytest.raises(OSError):
                 numpy.array(im_truncated)
         else:
-            with pytest.warns(DeprecationWarning):
+            with pytest.warns(DeprecationWarning, match="__array_interface__"):
                 numpy.array(im_truncated)
 
 
@@ -101,7 +102,8 @@ def test_fromarray_strides_without_tobytes() -> None:
 
     with pytest.raises(ValueError):
         wrapped = Wrapper({"shape": (1, 1), "strides": (1, 1)})
-        Image.fromarray(wrapped, "L")
+        with pytest.warns(DeprecationWarning, match="'mode' parameter"):
+            Image.fromarray(wrapped, "L")
 
 
 def test_fromarray_palette() -> None:
@@ -110,7 +112,8 @@ def test_fromarray_palette() -> None:
     a = numpy.array(i)
 
     # Act
-    out = Image.fromarray(a, "P")
+    with pytest.warns(DeprecationWarning, match="'mode' parameter"):
+        out = Image.fromarray(a, "P")
 
     # Assert that the Python and C palettes match
     assert out.palette is not None
