@@ -1,4 +1,7 @@
 from __future__ import annotations
+
+from pathlib import Path
+
 import pytest
 
 from PIL import Image
@@ -6,8 +9,8 @@ from PIL import Image
 from .helper import assert_image, assert_image_equal, assert_image_similar, hopper
 
 
-def test_sanity():
-    def convert(im, mode):
+def test_sanity() -> None:
+    def convert(im: Image.Image, mode: str) -> None:
         out = im.convert(mode)
         assert out.mode == mode
         assert out.size == im.size
@@ -39,13 +42,13 @@ def test_sanity():
             convert(im, output_mode)
 
 
-def test_unsupported_conversion():
+def test_unsupported_conversion() -> None:
     im = hopper()
     with pytest.raises(ValueError):
         im.convert("INVALID")
 
 
-def test_default():
+def test_default() -> None:
     im = hopper("P")
     assert im.mode == "P"
     converted_im = im.convert()
@@ -61,18 +64,18 @@ def test_default():
 # ref https://github.com/python-pillow/Pillow/issues/274
 
 
-def _test_float_conversion(im):
+def _test_float_conversion(im: Image.Image) -> None:
     orig = im.getpixel((5, 5))
     converted = im.convert("F").getpixel((5, 5))
     assert orig == converted
 
 
-def test_8bit():
+def test_8bit() -> None:
     with Image.open("Tests/images/hopper.jpg") as im:
         _test_float_conversion(im.convert("L"))
 
 
-def test_16bit():
+def test_16bit() -> None:
     with Image.open("Tests/images/16bit.cropped.tif") as im:
         _test_float_conversion(im)
 
@@ -82,19 +85,19 @@ def test_16bit():
         assert im_i16.getpixel((0, 0)) == 65535
 
 
-def test_16bit_workaround():
+def test_16bit_workaround() -> None:
     with Image.open("Tests/images/16bit.cropped.tif") as im:
         _test_float_conversion(im.convert("I"))
 
 
-def test_opaque():
+def test_opaque() -> None:
     alpha = hopper("P").convert("PA").getchannel("A")
 
     solid = Image.new("L", (128, 128), 255)
     assert_image_equal(alpha, solid)
 
 
-def test_rgba_p():
+def test_rgba_p() -> None:
     im = hopper("RGBA")
     im.putalpha(hopper("L"))
 
@@ -104,18 +107,18 @@ def test_rgba_p():
     assert_image_similar(im, comparable, 20)
 
 
-def test_rgba():
+def test_rgba() -> None:
     with Image.open("Tests/images/transparent.png") as im:
         assert im.mode == "RGBA"
 
         assert_image_similar(im.convert("RGBa").convert("RGB"), im.convert("RGB"), 1.5)
 
 
-def test_trns_p(tmp_path):
+def test_trns_p(tmp_path: Path) -> None:
     im = hopper("P")
     im.info["transparency"] = 0
 
-    f = str(tmp_path / "temp.png")
+    f = tmp_path / "temp.png"
 
     im_l = im.convert("L")
     assert im_l.info["transparency"] == 0
@@ -130,7 +133,7 @@ def test_trns_p(tmp_path):
 
 
 @pytest.mark.parametrize("mode", ("LA", "PA", "RGBA"))
-def test_trns_p_transparency(mode):
+def test_trns_p_transparency(mode: str) -> None:
     # Arrange
     im = hopper("P")
     im.info["transparency"] = 128
@@ -147,11 +150,11 @@ def test_trns_p_transparency(mode):
         assert converted_im.palette is None
 
 
-def test_trns_l(tmp_path):
+def test_trns_l(tmp_path: Path) -> None:
     im = hopper("L")
     im.info["transparency"] = 128
 
-    f = str(tmp_path / "temp.png")
+    f = tmp_path / "temp.png"
 
     im_la = im.convert("LA")
     assert "transparency" not in im_la.info
@@ -170,16 +173,24 @@ def test_trns_l(tmp_path):
     im_p.save(f)
 
 
-def test_trns_RGB(tmp_path):
+def test_trns_RGB(tmp_path: Path) -> None:
     im = hopper("RGB")
     im.info["transparency"] = im.getpixel((0, 0))
 
-    f = str(tmp_path / "temp.png")
+    f = tmp_path / "temp.png"
 
     im_l = im.convert("L")
     assert im_l.info["transparency"] == im_l.getpixel((0, 0))  # undone
     im_l.save(f)
 
+    im_la = im.convert("LA")
+    assert "transparency" not in im_la.info
+    im_la.save(f)
+
+    im_la = im.convert("La")
+    assert "transparency" not in im_la.info
+    assert im_la.getpixel((0, 0)) == (0, 0)
+
     im_p = im.convert("P")
     assert "transparency" in im_p.info
     im_p.save(f)
@@ -188,7 +199,14 @@ def test_trns_RGB(tmp_path):
     assert "transparency" not in im_rgba.info
     im_rgba.save(f)
 
-    im_p = pytest.warns(UserWarning, im.convert, "P", palette=Image.Palette.ADAPTIVE)
+    im_rgba = im.convert("RGBa")
+    assert "transparency" not in im_rgba.info
+    assert im_rgba.getpixel((0, 0)) == (0, 0, 0, 0)
+
+    with pytest.warns(
+        UserWarning, match="Couldn't allocate palette entry for transparency"
+    ):
+        im_p = im.convert("P", palette=Image.Palette.ADAPTIVE)
     assert "transparency" not in im_p.info
     im_p.save(f)
 
@@ -200,24 +218,26 @@ def test_trns_RGB(tmp_path):
 
 
 @pytest.mark.parametrize("convert_mode", ("L", "LA", "I"))
-def test_l_macro_rounding(convert_mode):
+def test_l_macro_rounding(convert_mode: str) -> None:
     for mode in ("P", "PA"):
         im = Image.new(mode, (1, 1))
+        assert im.palette is not None
         im.palette.getcolor((0, 1, 2))
 
         converted_im = im.convert(convert_mode)
-        px = converted_im.load()
-        converted_color = px[0, 0]
+        converted_color = converted_im.getpixel((0, 0))
         if convert_mode == "LA":
+            assert isinstance(converted_color, tuple)
             converted_color = converted_color[0]
         assert converted_color == 1
 
 
-def test_gif_with_rgba_palette_to_p():
+def test_gif_with_rgba_palette_to_p() -> None:
     # See https://github.com/python-pillow/Pillow/issues/2433
     with Image.open("Tests/images/hopper.gif") as im:
         im.info["transparency"] = 255
         im.load()
+        assert im.palette is not None
         assert im.palette.mode == "RGB"
         im_p = im.convert("P")
 
@@ -225,7 +245,7 @@ def test_gif_with_rgba_palette_to_p():
     im_p.load()
 
 
-def test_p_la():
+def test_p_la() -> None:
     im = hopper("RGBA")
     alpha = hopper("L")
     im.putalpha(alpha)
@@ -235,7 +255,7 @@ def test_p_la():
     assert_image_similar(alpha, comparable, 5)
 
 
-def test_p2pa_alpha():
+def test_p2pa_alpha() -> None:
     with Image.open("Tests/images/tiny.png") as im:
         assert im.mode == "P"
 
@@ -249,13 +269,13 @@ def test_p2pa_alpha():
             assert im_a.getpixel((x, y)) == alpha
 
 
-def test_p2pa_palette():
+def test_p2pa_palette() -> None:
     with Image.open("Tests/images/tiny.png") as im:
         im_pa = im.convert("PA")
     assert im_pa.getpalette() == im.getpalette()
 
 
-def test_matrix_illegal_conversion():
+def test_matrix_illegal_conversion() -> None:
     # Arrange
     im = hopper("CMYK")
     # fmt: off
@@ -271,7 +291,7 @@ def test_matrix_illegal_conversion():
         im.convert(mode="CMYK", matrix=matrix)
 
 
-def test_matrix_wrong_mode():
+def test_matrix_wrong_mode() -> None:
     # Arrange
     im = hopper("L")
     # fmt: off
@@ -288,7 +308,7 @@ def test_matrix_wrong_mode():
 
 
 @pytest.mark.parametrize("mode", ("RGB", "L"))
-def test_matrix_xyz(mode):
+def test_matrix_xyz(mode: str) -> None:
     # Arrange
     im = hopper("RGB")
     im.info["transparency"] = (255, 0, 0)
@@ -316,7 +336,7 @@ def test_matrix_xyz(mode):
             assert converted_im.info["transparency"] == 105
 
 
-def test_matrix_identity():
+def test_matrix_identity() -> None:
     # Arrange
     im = hopper("RGB")
     # fmt: off
