@@ -81,7 +81,7 @@ def test_mode_F() -> None:
 @pytest.mark.parametrize("mode", ("BGR;15", "BGR;16", "BGR;24"))
 def test_mode_BGR(mode: str) -> None:
     data = [(16, 32, 49), (32, 32, 98)]
-    with pytest.warns(DeprecationWarning):
+    with pytest.warns(DeprecationWarning, match=mode):
         im = Image.new(mode, (1, 2))
     im.putdata(data)
 
