@@ -1,10 +1,11 @@
 from __future__ import annotations
+
 import pytest
 
 from .helper import assert_image_equal, fromstring, hopper
 
 
-def test_sanity():
+def test_sanity() -> None:
     with pytest.raises(ValueError):
         hopper().tobitmap()
 
