@@ -4,13 +4,13 @@ from pathlib import Path
 
 import pytest
 
-from PIL import Image, ImageSequence, TiffImagePlugin
+from PIL import Image, ImageSequence, PsdImagePlugin, TiffImagePlugin
 
 from .helper import assert_image_equal, hopper, skip_unless_feature
 
 
 def test_sanity(tmp_path: Path) -> None:
-    test_file = str(tmp_path / "temp.im")
+    test_file = tmp_path / "temp.im"
 
     im = hopper("RGB")
     im.save(test_file)
@@ -31,8 +31,9 @@ def test_sanity(tmp_path: Path) -> None:
 
 def test_iterator() -> None:
     with Image.open("Tests/images/multipage.tiff") as im:
+        assert isinstance(im, TiffImagePlugin.TiffImageFile)
         i = ImageSequence.Iterator(im)
-        for index in range(0, im.n_frames):
+        for index in range(im.n_frames):
             assert i[index] == next(i)
         with pytest.raises(IndexError):
             i[index + 1]
@@ -42,6 +43,7 @@ def test_iterator() -> None:
 
 def test_iterator_min_frame() -> None:
     with Image.open("Tests/images/hopper.psd") as im:
+        assert isinstance(im, PsdImagePlugin.PsdImageFile)
         i = ImageSequence.Iterator(im)
         for index in range(1, im.n_frames):
             assert i[index] == next(i)
