@@ -8,8 +8,8 @@ from __future__ import annotations
 
 import re
 import subprocess
-from typing import TYPE_CHECKING
 
+TYPE_CHECKING = False
 if TYPE_CHECKING:
     from sphinx.application import Sphinx
 
