@@ -24,12 +24,13 @@ from __future__ import annotations
 
 from . import Image
 from ._binary import i32le as i32
+from ._util import DeferredError
 from .PcxImagePlugin import PcxImageFile
 
 MAGIC = 0x3ADE68B1  # QUIZ: what's this value, then?
 
 
-def _accept(prefix):
+def _accept(prefix: bytes) -> bool:
     return len(prefix) >= 4 and i32(prefix) == MAGIC
 
 
@@ -42,7 +43,7 @@ class DcxImageFile(PcxImageFile):
     format_description = "Intel DCX"
     _close_exclusive_fp_after_loading = False
 
-    def _open(self):
+    def _open(self) -> None:
         # Header
         s = self.fp.read(4)
         if not _accept(s):
@@ -58,20 +59,22 @@ class DcxImageFile(PcxImageFile):
             self._offset.append(offset)
 
         self._fp = self.fp
-        self.frame = None
+        self.frame = -1
         self.n_frames = len(self._offset)
         self.is_animated = self.n_frames > 1
         self.seek(0)
 
-    def seek(self, frame):
+    def seek(self, frame: int) -> None:
         if not self._seek_check(frame):
             return
+        if isinstance(self._fp, DeferredError):
+            raise self._fp.ex
         self.frame = frame
         self.fp = self._fp
         self.fp.seek(self._offset[frame])
         PcxImageFile._open(self)
 
-    def tell(self):
+    def tell(self) -> int:
         return self.frame
 
 
