@@ -36,7 +36,8 @@
 #define UINT32_MAX 0xffffffff
 #endif
 
-#define NO_OUTPUT
+// #define DEBUG
+// #define TEST_NEAREST_NEIGHBOUR
 
 typedef struct {
     uint32_t scale;
@@ -103,7 +104,8 @@ static uint32_t
 pixel_hash(const HashTable *h, const Pixel pixel) {
     PixelHashData *d = (PixelHashData *)hashtable_get_user_data(h);
     return PIXEL_HASH(
-        pixel.c.r >> d->scale, pixel.c.g >> d->scale, pixel.c.b >> d->scale);
+        pixel.c.r >> d->scale, pixel.c.g >> d->scale, pixel.c.b >> d->scale
+    );
 }
 
 static int
@@ -111,9 +113,11 @@ pixel_cmp(const HashTable *h, const Pixel pixel1, const Pixel pixel2) {
     PixelHashData *d = (PixelHashData *)hashtable_get_user_data(h);
     uint32_t A, B;
     A = PIXEL_HASH(
-        pixel1.c.r >> d->scale, pixel1.c.g >> d->scale, pixel1.c.b >> d->scale);
+        pixel1.c.r >> d->scale, pixel1.c.g >> d->scale, pixel1.c.b >> d->scale
+    );
     B = PIXEL_HASH(
-        pixel2.c.r >> d->scale, pixel2.c.g >> d->scale, pixel2.c.b >> d->scale);
+        pixel2.c.r >> d->scale, pixel2.c.g >> d->scale, pixel2.c.b >> d->scale
+    );
     return (A == B) ? 0 : ((A < B) ? -1 : 1);
 }
 
@@ -129,7 +133,8 @@ new_count_func(const HashTable *h, const Pixel key, uint32_t *val) {
 
 static void
 rehash_collide(
-    const HashTable *h, Pixel *keyp, uint32_t *valp, Pixel newkey, uint32_t newval) {
+    const HashTable *h, Pixel *keyp, uint32_t *valp, Pixel newkey, uint32_t newval
+) {
     *valp += newval;
 }
 
@@ -140,7 +145,7 @@ create_pixel_hash(Pixel *pixelData, uint32_t nPixels) {
     PixelHashData *d;
     HashTable *hash;
     uint32_t i;
-#ifndef NO_OUTPUT
+#ifdef DEBUG
     uint32_t timer, timer2, timer3;
 #endif
 
@@ -152,32 +157,33 @@ create_pixel_hash(Pixel *pixelData, uint32_t nPixels) {
     hash = hashtable_new(pixel_hash, pixel_cmp);
     hashtable_set_user_data(hash, d);
     d->scale = 0;
-#ifndef NO_OUTPUT
+#ifdef DEBUG
     timer = timer3 = clock();
 #endif
     for (i = 0; i < nPixels; i++) {
         if (!hashtable_insert_or_update_computed(
-                hash, pixelData[i], new_count_func, exists_count_func)) {
+                hash, pixelData[i], new_count_func, exists_count_func
+            )) {
             ;
         }
         while (hashtable_get_count(hash) > MAX_HASH_ENTRIES) {
             d->scale++;
-#ifndef NO_OUTPUT
+#ifdef DEBUG
             printf("rehashing - new scale: %d\n", (int)d->scale);
             timer2 = clock();
 #endif
             hashtable_rehash_compute(hash, rehash_collide);
-#ifndef NO_OUTPUT
+#ifdef DEBUG
             timer2 = clock() - timer2;
             printf("rehash took %f sec\n", timer2 / (double)CLOCKS_PER_SEC);
             timer += timer2;
 #endif
         }
     }
-#ifndef NO_OUTPUT
+#ifdef DEBUG
     printf("inserts took %f sec\n", (clock() - timer) / (double)CLOCKS_PER_SEC);
 #endif
-#ifndef NO_OUTPUT
+#ifdef DEBUG
     printf("total        %f sec\n", (clock() - timer3) / (double)CLOCKS_PER_SEC);
 #endif
     return hash;
@@ -299,18 +305,18 @@ mergesort_pixels(PixelList *head, int i) {
     return head;
 }
 
-#if defined(TEST_MERGESORT) || defined(TEST_SORTED)
+#ifdef DEBUG
 static int
 test_sorted(PixelList *pl[3]) {
-    int i, n, l;
+    int i, l;
     PixelList *t;
 
     for (i = 0; i < 3; i++) {
-        n = 0;
         l = 256;
         for (t = pl[i]; t; t = t->next[i]) {
-            if (l < t->p.a.v[i])
+            if (l < t->p.a.v[i]) {
                 return 0;
+            }
             l = t->p.a.v[i];
         }
     }
@@ -335,18 +341,19 @@ splitlists(
     PixelList *nt[2][3],
     uint32_t nCount[2],
     int axis,
-    uint32_t pixelCount) {
+    uint32_t pixelCount
+) {
     uint32_t left;
 
     PixelList *l, *r, *c, *n;
     int i;
     int nRight;
-#ifndef NO_OUTPUT
+#ifdef DEBUG
     int nLeft;
 #endif
     int splitColourVal;
 
-#ifdef TEST_SPLIT
+#ifdef DEBUG
     {
         PixelList *_prevTest, *_nextTest;
         int _i, _nextCount[3], _prevCount[3];
@@ -387,7 +394,8 @@ splitlists(
                     _prevCount[2],
                     _nextCount[0],
                     _nextCount[1],
-                    _nextCount[2]);
+                    _nextCount[2]
+                );
                 exit(1);
             }
         }
@@ -395,14 +403,14 @@ splitlists(
 #endif
     nCount[0] = nCount[1] = 0;
     nRight = 0;
-#ifndef NO_OUTPUT
+#ifdef DEBUG
     nLeft = 0;
 #endif
     for (left = 0, c = h[axis]; c;) {
         left = left + c->count;
         nCount[0] += c->count;
         c->flag = 0;
-#ifndef NO_OUTPUT
+#ifdef DEBUG
         nLeft++;
 #endif
         c = c->next[axis];
@@ -417,7 +425,7 @@ splitlists(
                 break;
             }
             c->flag = 0;
-#ifndef NO_OUTPUT
+#ifdef DEBUG
             nLeft++;
 #endif
             nCount[0] += c->count;
@@ -435,14 +443,14 @@ splitlists(
             }
             c->flag = 1;
             nRight++;
-#ifndef NO_OUTPUT
+#ifdef DEBUG
             nLeft--;
 #endif
             nCount[0] -= c->count;
             nCount[1] += c->count;
         }
     }
-#ifndef NO_OUTPUT
+#ifdef DEBUG
     if (!nLeft) {
         for (c = h[axis]; c; c = c->next[axis]) {
             printf("[%d %d %d]\n", c->p.c.r, c->p.c.g, c->p.c.b);
@@ -504,7 +512,7 @@ split(BoxNode *node) {
     gl = node->tail[1]->p.c.g;
     bh = node->head[2]->p.c.b;
     bl = node->tail[2]->p.c.b;
-#ifdef TEST_SPLIT
+#ifdef DEBUG
     printf("splitting node [%d %d %d] [%d %d %d] ", rl, gl, bl, rh, gh, bh);
 #endif
     f[0] = (rh - rl) * 77;
@@ -519,11 +527,8 @@ split(BoxNode *node) {
             axis = i;
         }
     }
-#ifdef TEST_SPLIT
+#ifdef DEBUG
     printf("along axis %d\n", axis + 1);
-#endif
-
-#ifdef TEST_SPLIT
     {
         PixelList *_prevTest, *_nextTest;
         int _i, _nextCount[3], _prevCount[3];
@@ -531,12 +536,14 @@ split(BoxNode *node) {
             if (node->tail[_i]->next[_i]) {
                 printf("tail is not tail\n");
                 printf(
-                    "node->tail[%d]->next[%d]=%p\n", _i, _i, node->tail[_i]->next[_i]);
+                    "node->tail[%d]->next[%d]=%p\n", _i, _i, node->tail[_i]->next[_i]
+                );
             }
             if (node->head[_i]->prev[_i]) {
                 printf("head is not head\n");
                 printf(
-                    "node->head[%d]->prev[%d]=%p\n", _i, _i, node->head[_i]->prev[_i]);
+                    "node->head[%d]->prev[%d]=%p\n", _i, _i, node->head[_i]->prev[_i]
+                );
             }
         }
 
@@ -573,20 +580,22 @@ split(BoxNode *node) {
                     _prevCount[2],
                     _nextCount[0],
                     _nextCount[1],
-                    _nextCount[2]);
+                    _nextCount[2]
+                );
             }
         }
     }
 #endif
     node->axis = axis;
     if (!splitlists(
-            node->head, node->tail, heads, tails, newCounts, axis, node->pixelCount)) {
-#ifndef NO_OUTPUT
+            node->head, node->tail, heads, tails, newCounts, axis, node->pixelCount
+        )) {
+#ifdef DEBUG
         printf("list split failed.\n");
 #endif
         return 0;
     }
-#ifdef TEST_SPLIT
+#ifdef DEBUG
     if (!test_sorted(heads[0])) {
         printf("bug in split");
         exit(1);
@@ -612,7 +621,7 @@ split(BoxNode *node) {
         node->head[i] = NULL;
         node->tail[i] = NULL;
     }
-#ifdef TEST_SPLIT
+#ifdef DEBUG
     if (left->head[0]) {
         rh = left->head[0]->p.c.r;
         rl = left->tail[0]->p.c.r;
@@ -676,7 +685,7 @@ median_cut(PixelList *hl[3], uint32_t imPixelCount, int nPixels) {
             }
         } while (compute_box_volume(thisNode) == 1);
         if (!split(thisNode)) {
-#ifndef NO_OUTPUT
+#ifdef DEBUG
             printf("Oops, split failed...\n");
 #endif
             exit(1);
@@ -705,16 +714,14 @@ free_box_tree(BoxNode *n) {
     free(n);
 }
 
-#ifdef TEST_SPLIT_INTEGRITY
+#ifdef DEBUG
 static int
 checkContained(BoxNode *n, Pixel *pp) {
     if (n->l && n->r) {
         return checkContained(n->l, pp) + checkContained(n->r, pp);
     }
     if (n->l || n->r) {
-#ifndef NO_OUTPUT
         printf("box tree is dead\n");
-#endif
         return 0;
     }
     if (pp->c.r <= n->head[0]->p.c.r && pp->c.r >= n->tail[0]->p.c.r &&
@@ -735,7 +742,7 @@ annotate_hash_table(BoxNode *n, HashTable *h, uint32_t *box) {
         return annotate_hash_table(n->l, h, box) && annotate_hash_table(n->r, h, box);
     }
     if (n->l || n->r) {
-#ifndef NO_OUTPUT
+#ifdef DEBUG
         printf("box tree is dead\n");
 #endif
         return 0;
@@ -743,7 +750,7 @@ annotate_hash_table(BoxNode *n, HashTable *h, uint32_t *box) {
     for (p = n->head[0]; p; p = p->next[0]) {
         PIXEL_UNSCALE(&(p->p), &q, d->scale);
         if (!hashtable_insert(h, q, *box)) {
-#ifndef NO_OUTPUT
+#ifdef DEBUG
             printf("hashtable insert failed\n");
 #endif
             return 0;
@@ -772,7 +779,8 @@ _distance_index_cmp(const void *a, const void *b) {
 
 static int
 resort_distance_tables(
-    uint32_t *avgDist, uint32_t **avgDistSortKey, Pixel *p, uint32_t nEntries) {
+    uint32_t *avgDist, uint32_t **avgDistSortKey, Pixel *p, uint32_t nEntries
+) {
     uint32_t i, j, k;
     uint32_t **skRow;
     uint32_t *skElt;
@@ -801,7 +809,8 @@ resort_distance_tables(
 
 static int
 build_distance_tables(
-    uint32_t *avgDist, uint32_t **avgDistSortKey, Pixel *p, uint32_t nEntries) {
+    uint32_t *avgDist, uint32_t **avgDistSortKey, Pixel *p, uint32_t nEntries
+) {
     uint32_t i, j;
     DistanceWithIndex *dwi;
 
@@ -841,7 +850,8 @@ map_image_pixels(
     uint32_t nPaletteEntries,
     uint32_t *avgDist,
     uint32_t **avgDistSortKey,
-    uint32_t *pixelArray) {
+    uint32_t *pixelArray
+) {
     uint32_t *aD, **aDSK;
     uint32_t idx;
     uint32_t i, j;
@@ -888,7 +898,8 @@ map_image_pixels_from_quantized_pixels(
     uint32_t **avgDistSortKey,
     uint32_t *pixelArray,
     uint32_t *avg[3],
-    uint32_t *count) {
+    uint32_t *count
+) {
     uint32_t *aD, **aDSK;
     uint32_t idx;
     uint32_t i, j;
@@ -946,7 +957,8 @@ map_image_pixels_from_median_box(
     HashTable *medianBoxHash,
     uint32_t *avgDist,
     uint32_t **avgDistSortKey,
-    uint32_t *pixelArray) {
+    uint32_t *pixelArray
+) {
     uint32_t *aD, **aDSK;
     uint32_t idx;
     uint32_t i, j;
@@ -962,7 +974,7 @@ map_image_pixels_from_median_box(
             continue;
         }
         if (!hashtable_lookup(medianBoxHash, pixelData[i], &pixelVal)) {
-#ifndef NO_OUTPUT
+#ifdef DEBUG
             printf("pixel lookup failed\n");
 #endif
             return 0;
@@ -998,7 +1010,9 @@ compute_palette_from_median_cut(
     uint32_t nPixels,
     HashTable *medianBoxHash,
     Pixel **palette,
-    uint32_t nPaletteEntries) {
+    uint32_t nPaletteEntries,
+    BoxNode *root
+) {
     uint32_t i;
     uint32_t paletteEntry;
     Pixel *p;
@@ -1026,7 +1040,7 @@ compute_palette_from_median_cut(
         }
     }
     for (i = 0; i < nPixels; i++) {
-#ifdef TEST_SPLIT_INTEGRITY
+#ifdef DEBUG
         if (!(i % 100)) {
             printf("%05d\r", i);
             fflush(stdout);
@@ -1041,7 +1055,7 @@ compute_palette_from_median_cut(
         }
 #endif
         if (!hashtable_lookup(medianBoxHash, pixelData[i], &paletteEntry)) {
-#ifndef NO_OUTPUT
+#ifdef DEBUG
             printf("pixel lookup failed\n");
 #endif
             for (i = 0; i < 3; i++) {
@@ -1051,11 +1065,12 @@ compute_palette_from_median_cut(
             return 0;
         }
         if (paletteEntry >= nPaletteEntries) {
-#ifndef NO_OUTPUT
+#ifdef DEBUG
             printf(
                 "panic - paletteEntry>=nPaletteEntries (%d>=%d)\n",
                 (int)paletteEntry,
-                (int)nPaletteEntries);
+                (int)nPaletteEntries
+            );
 #endif
             for (i = 0; i < 3; i++) {
                 free(avg[i]);
@@ -1092,7 +1107,8 @@ compute_palette_from_median_cut(
 
 static int
 recompute_palette_from_averages(
-    Pixel *palette, uint32_t nPaletteEntries, uint32_t *avg[3], uint32_t *count) {
+    Pixel *palette, uint32_t nPaletteEntries, uint32_t *avg[3], uint32_t *count
+) {
     uint32_t i;
 
     for (i = 0; i < nPaletteEntries; i++) {
@@ -1111,7 +1127,8 @@ compute_palette_from_quantized_pixels(
     uint32_t nPaletteEntries,
     uint32_t *avg[3],
     uint32_t *count,
-    uint32_t *qp) {
+    uint32_t *qp
+) {
     uint32_t i;
 
     memset(count, 0, sizeof(uint32_t) * nPaletteEntries);
@@ -1120,7 +1137,7 @@ compute_palette_from_quantized_pixels(
     }
     for (i = 0; i < nPixels; i++) {
         if (qp[i] >= nPaletteEntries) {
-#ifndef NO_OUTPUT
+#ifdef DEBUG
             printf("scream\n");
 #endif
             return 0;
@@ -1145,7 +1162,8 @@ k_means(
     Pixel *paletteData,
     uint32_t nPaletteEntries,
     uint32_t *qp,
-    int threshold) {
+    int threshold
+) {
     uint32_t *avg[3];
     uint32_t *count;
     uint32_t i;
@@ -1187,23 +1205,26 @@ k_means(
         goto error_2;
     }
 
-#ifndef NO_OUTPUT
+#ifdef DEBUG
     printf("[");
     fflush(stdout);
 #endif
     while (1) {
         if (!built) {
             compute_palette_from_quantized_pixels(
-                pixelData, nPixels, paletteData, nPaletteEntries, avg, count, qp);
+                pixelData, nPixels, paletteData, nPaletteEntries, avg, count, qp
+            );
             if (!build_distance_tables(
-                    avgDist, avgDistSortKey, paletteData, nPaletteEntries)) {
+                    avgDist, avgDistSortKey, paletteData, nPaletteEntries
+                )) {
                 goto error_3;
             }
             built = 1;
         } else {
             recompute_palette_from_averages(paletteData, nPaletteEntries, avg, count);
             resort_distance_tables(
-                avgDist, avgDistSortKey, paletteData, nPaletteEntries);
+                avgDist, avgDistSortKey, paletteData, nPaletteEntries
+            );
         }
         changes = map_image_pixels_from_quantized_pixels(
             pixelData,
@@ -1214,11 +1235,12 @@ k_means(
             avgDistSortKey,
             qp,
             avg,
-            count);
+            count
+        );
         if (changes < 0) {
             goto error_3;
         }
-#ifndef NO_OUTPUT
+#ifdef DEBUG
         printf(".(%d)", changes);
         fflush(stdout);
 #endif
@@ -1226,7 +1248,7 @@ k_means(
             break;
         }
     }
-#ifndef NO_OUTPUT
+#ifdef DEBUG
     printf("]\n");
 #endif
     if (avgDistSortKey) {
@@ -1273,7 +1295,8 @@ quantize(
     Pixel **palette,
     uint32_t *paletteLength,
     uint32_t **quantizedPixels,
-    int kmeans) {
+    int kmeans
+) {
     PixelList *hl[3];
     HashTable *h;
     BoxNode *root;
@@ -1285,32 +1308,32 @@ quantize(
     uint32_t **avgDistSortKey;
     Pixel *p;
 
-#ifndef NO_OUTPUT
+#ifdef DEBUG
     uint32_t timer, timer2;
 #endif
 
-#ifndef NO_OUTPUT
+#ifdef DEBUG
     timer2 = clock();
     printf("create hash table...");
     fflush(stdout);
     timer = clock();
 #endif
     h = create_pixel_hash(pixelData, nPixels);
-#ifndef NO_OUTPUT
+#ifdef DEBUG
     printf("done (%f)\n", (clock() - timer) / (double)CLOCKS_PER_SEC);
 #endif
     if (!h) {
         goto error_0;
     }
 
-#ifndef NO_OUTPUT
+#ifdef DEBUG
     printf("create lists from hash table...");
     fflush(stdout);
     timer = clock();
 #endif
     hl[0] = hl[1] = hl[2] = NULL;
     hashtable_foreach(h, hash_to_list, hl);
-#ifndef NO_OUTPUT
+#ifdef DEBUG
     printf("done (%f)\n", (clock() - timer) / (double)CLOCKS_PER_SEC);
 #endif
 
@@ -1318,7 +1341,7 @@ quantize(
         goto error_1;
     }
 
-#ifndef NO_OUTPUT
+#ifdef DEBUG
     printf("mergesort lists...");
     fflush(stdout);
     timer = clock();
@@ -1326,47 +1349,47 @@ quantize(
     for (i = 0; i < 3; i++) {
         hl[i] = mergesort_pixels(hl[i], i);
     }
-#ifdef TEST_MERGESORT
+#ifdef DEBUG
     if (!test_sorted(hl)) {
         printf("bug in mergesort\n");
         goto error_1;
     }
-#endif
-#ifndef NO_OUTPUT
     printf("done (%f)\n", (clock() - timer) / (double)CLOCKS_PER_SEC);
 #endif
 
-#ifndef NO_OUTPUT
+#ifdef DEBUG
     printf("median cut...");
     fflush(stdout);
     timer = clock();
 #endif
     root = median_cut(hl, nPixels, nQuantPixels);
-#ifndef NO_OUTPUT
+#ifdef DEBUG
     printf("done (%f)\n", (clock() - timer) / (double)CLOCKS_PER_SEC);
 #endif
     if (!root) {
         goto error_1;
     }
     nPaletteEntries = 0;
-#ifndef NO_OUTPUT
+#ifdef DEBUG
     printf("median cut tree to hash table...");
     fflush(stdout);
     timer = clock();
 #endif
     annotate_hash_table(root, h, &nPaletteEntries);
-#ifndef NO_OUTPUT
+#ifdef DEBUG
     printf("done (%f)\n", (clock() - timer) / (double)CLOCKS_PER_SEC);
 #endif
-#ifndef NO_OUTPUT
+#ifdef DEBUG
     printf("compute palette...\n");
     fflush(stdout);
     timer = clock();
 #endif
-    if (!compute_palette_from_median_cut(pixelData, nPixels, h, &p, nPaletteEntries)) {
+    if (!compute_palette_from_median_cut(
+            pixelData, nPixels, h, &p, nPaletteEntries, root
+        )) {
         goto error_3;
     }
-#ifndef NO_OUTPUT
+#ifdef DEBUG
     printf("done (%f)\n", (clock() - timer) / (double)CLOCKS_PER_SEC);
 #endif
 
@@ -1399,7 +1422,8 @@ quantize(
     }
 
     if (!map_image_pixels_from_median_box(
-            pixelData, nPixels, p, nPaletteEntries, h, avgDist, avgDistSortKey, qp)) {
+            pixelData, nPixels, p, nPaletteEntries, h, avgDist, avgDistSortKey, qp
+        )) {
         goto error_7;
     }
 
@@ -1445,13 +1469,14 @@ quantize(
                                   _SQR(pixelData[i].c.b - p[qp[i]].c.b))),
                     sqrt((double)(_SQR(pixelData[i].c.r - p[bestmatch].c.r) +
                                   _SQR(pixelData[i].c.g - p[bestmatch].c.g) +
-                                  _SQR(pixelData[i].c.b - p[bestmatch].c.b))));
+                                  _SQR(pixelData[i].c.b - p[bestmatch].c.b)))
+                );
             }
         }
         hashtable_free(h2);
     }
 #endif
-#ifndef NO_OUTPUT
+#ifdef DEBUG
     printf("k means...\n");
     fflush(stdout);
     timer = clock();
@@ -1459,7 +1484,7 @@ quantize(
     if (kmeans > 0) {
         k_means(pixelData, nPixels, p, nPaletteEntries, qp, kmeans - 1);
     }
-#ifndef NO_OUTPUT
+#ifdef DEBUG
     printf("done (%f)\n", (clock() - timer) / (double)CLOCKS_PER_SEC);
 #endif
 
@@ -1467,7 +1492,7 @@ quantize(
     *palette = p;
     *paletteLength = nPaletteEntries;
 
-#ifndef NO_OUTPUT
+#ifdef DEBUG
     printf("cleanup...");
     fflush(stdout);
     timer = clock();
@@ -1479,7 +1504,7 @@ quantize(
         free(avgDistSortKey);
     }
     destroy_pixel_hash(h);
-#ifndef NO_OUTPUT
+#ifdef DEBUG
     printf("done (%f)\n", (clock() - timer) / (double)CLOCKS_PER_SEC);
     printf("-----\ntotal time %f\n", (clock() - timer2) / (double)CLOCKS_PER_SEC);
 #endif
@@ -1545,7 +1570,8 @@ quantize2(
     Pixel **palette,
     uint32_t *paletteLength,
     uint32_t **quantizedPixels,
-    int kmeans) {
+    int kmeans
+) {
     HashTable *h;
     uint32_t i;
     uint32_t mean[3];
@@ -1609,7 +1635,8 @@ quantize2(
     }
 
     if (!map_image_pixels(
-            pixelData, nPixels, p, nQuantPixels, avgDist, avgDistSortKey, qp)) {
+            pixelData, nPixels, p, nQuantPixels, avgDist, avgDistSortKey, qp
+        )) {
         goto error_4;
     }
     if (kmeans > 0) {
@@ -1752,7 +1779,8 @@ ImagingQuantize(Imaging im, int colors, int mode, int kmeans) {
                 &palette,
                 &paletteLength,
                 &newData,
-                kmeans);
+                kmeans
+            );
             break;
         case 1:
             /* maximum coverage */
@@ -1763,7 +1791,8 @@ ImagingQuantize(Imaging im, int colors, int mode, int kmeans) {
                 &palette,
                 &paletteLength,
                 &newData,
-                kmeans);
+                kmeans
+            );
             break;
         case 2:
             result = quantize_octree(
@@ -1773,7 +1802,8 @@ ImagingQuantize(Imaging im, int colors, int mode, int kmeans) {
                 &palette,
                 &paletteLength,
                 &newData,
-                withAlpha);
+                withAlpha
+            );
             break;
         case 3:
 #ifdef HAVE_LIBIMAGEQUANT
@@ -1785,7 +1815,8 @@ ImagingQuantize(Imaging im, int colors, int mode, int kmeans) {
                 &palette,
                 &paletteLength,
                 &newData,
-                withAlpha);
+                withAlpha
+            );
 #else
             result = -1;
 #endif
@@ -1836,7 +1867,8 @@ ImagingQuantize(Imaging im, int colors, int mode, int kmeans) {
         if (result == -1) {
             return (Imaging)ImagingError_ValueError(
                 "dependency required by this method was not "
-                "enabled at compile time");
+                "enabled at compile time"
+            );
         }
 
         return (Imaging)ImagingError_ValueError("quantization error");
