@@ -57,7 +57,10 @@ def cmd_nmake(
 
 
 def cmds_cmake(
-    target: str | tuple[str, ...] | list[str], *params: str, build_dir: str = "."
+    target: str | tuple[str, ...] | list[str],
+    *params: str,
+    build_dir: str = ".",
+    build_type: str = "Release",
 ) -> list[str]:
     if not isinstance(target, str):
         target = " ".join(target)
@@ -66,7 +69,7 @@ def cmds_cmake(
         " ".join(
             [
                 "{cmake}",
-                "-DCMAKE_BUILD_TYPE=Release",
+                f"-DCMAKE_BUILD_TYPE={build_type}",
                 "-DCMAKE_VERBOSE_MAKEFILE=ON",
                 "-DCMAKE_RULE_MESSAGES:BOOL=OFF",  # for NMake
                 "-DCMAKE_C_COMPILER=cl.exe",  # for Ninja
@@ -113,17 +116,18 @@ V = {
     "BROTLI": "1.1.0",
     "FREETYPE": "2.13.3",
     "FRIBIDI": "1.0.16",
-    "HARFBUZZ": "10.1.0",
-    "JPEGTURBO": "3.1.0",
-    "LCMS2": "2.16",
-    "LIBPNG": "1.6.44",
+    "HARFBUZZ": "11.2.1",
+    "JPEGTURBO": "3.1.1",
+    "LCMS2": "2.17",
+    "LIBAVIF": "1.3.0",
+    "LIBIMAGEQUANT": "4.3.4",
+    "LIBPNG": "1.6.49",
     "LIBWEBP": "1.5.0",
     "OPENJPEG": "2.5.3",
-    "TIFF": "4.6.0",
-    "XZ": "5.6.3",
-    "ZLIBNG": "2.2.2",
+    "TIFF": "4.7.0",
+    "XZ": "5.8.1",
+    "ZLIBNG": "2.2.4",
 }
-V["LIBPNG_DOTLESS"] = V["LIBPNG"].replace(".", "")
 V["LIBPNG_XY"] = "".join(V["LIBPNG"].split(".")[:2])
 
 
@@ -180,7 +184,11 @@ DEPS: dict[str, dict[str, Any]] = {
         "filename": f"xz-{V['XZ']}.tar.gz",
         "license": "COPYING",
         "build": [
-            *cmds_cmake("liblzma", "-DBUILD_SHARED_LIBS:BOOL=OFF"),
+            *cmds_cmake(
+                "liblzma",
+                "-DBUILD_SHARED_LIBS:BOOL=OFF"
+                + (" -DXZ_CLMUL_CRC:BOOL=OFF" if struct.calcsize("P") == 4 else ""),
+            ),
             cmd_mkdir(r"{inc_dir}\lzma"),
             cmd_copy(r"src\liblzma\api\lzma\*.h", r"{inc_dir}\lzma"),
         ],
@@ -234,6 +242,7 @@ DEPS: dict[str, dict[str, Any]] = {
                 "-DBUILD_SHARED_LIBS:BOOL=OFF",
                 "-DWebP_LIBRARY=libwebp",
                 '-DCMAKE_C_FLAGS="-nologo -DLZMA_API_STATIC"',
+                "-DCMAKE_POLICY_VERSION_MINIMUM=3.5",
             )
         ],
         "headers": [r"libtiff\tiff*.h"],
@@ -241,8 +250,8 @@ DEPS: dict[str, dict[str, Any]] = {
     },
     "libpng": {
         "url": f"{SF_PROJECTS}/libpng/files/libpng{V['LIBPNG_XY']}/{V['LIBPNG']}/"
-        f"lpng{V['LIBPNG_DOTLESS']}.zip/download",
-        "filename": f"lpng{V['LIBPNG_DOTLESS']}.zip",
+        f"FILENAME/download",
+        "filename": f"libpng-{V['LIBPNG']}.tar.gz",
         "license": "LICENSE",
         "build": [
             *cmds_cmake("png_static", "-DPNG_SHARED:BOOL=OFF", "-DPNG_TESTS:BOOL=OFF"),
@@ -336,28 +345,19 @@ DEPS: dict[str, dict[str, Any]] = {
         "libs": [r"bin\*.lib"],
     },
     "libimagequant": {
-        # commit: Merge branch 'master' into msvc (matches 2.17.0 tag)
-        "url": "https://github.com/ImageOptim/libimagequant/archive/e4c1334be0eff290af5e2b4155057c2953a313ab.zip",
-        "filename": "libimagequant-e4c1334be0eff290af5e2b4155057c2953a313ab.zip",
+        "url": "https://github.com/ImageOptim/libimagequant/archive/{V['LIBIMAGEQUANT']}.tar.gz",
+        "filename": f"libimagequant-{V['LIBIMAGEQUANT']}.tar.gz",
         "license": "COPYRIGHT",
-        "patch": {
-            "CMakeLists.txt": {
-                "if(OPENMP_FOUND)": "if(false)",
-                "install": "#install",
-                # libimagequant does not detect MSVC x86_arm64 cross-compiler correctly
-                "if(${{CMAKE_SYSTEM_PROCESSOR}} STREQUAL ARM64)": "if({architecture} STREQUAL ARM64)",  # noqa: E501
-            }
-        },
         "build": [
-            *cmds_cmake("imagequant_a"),
-            cmd_copy("imagequant_a.lib", "imagequant.lib"),
+            cmd_cd("imagequant-sys"),
+            "cargo build --release",
         ],
-        "headers": [r"*.h"],
-        "libs": [r"imagequant.lib"],
+        "headers": ["libimagequant.h"],
+        "libs": [r"..\target\release\imagequant_sys.lib"],
     },
     "harfbuzz": {
-        "url": f"https://github.com/harfbuzz/harfbuzz/archive/{V['HARFBUZZ']}.zip",
-        "filename": f"harfbuzz-{V['HARFBUZZ']}.zip",
+        "url": f"https://github.com/harfbuzz/harfbuzz/releases/download/{V['HARFBUZZ']}/FILENAME",
+        "filename": f"harfbuzz-{V['HARFBUZZ']}.tar.xz",
         "license": "COPYING",
         "build": [
             *cmds_cmake(
@@ -387,6 +387,29 @@ DEPS: dict[str, dict[str, Any]] = {
         ],
         "bins": [r"*.dll"],
     },
+    "libavif": {
+        "url": f"https://github.com/AOMediaCodec/libavif/archive/v{V['LIBAVIF']}.tar.gz",
+        "filename": f"libavif-{V['LIBAVIF']}.tar.gz",
+        "license": "LICENSE",
+        "build": [
+            "rustup update",
+            f"{sys.executable} -m pip install meson",
+            *cmds_cmake(
+                "avif_static",
+                "-DBUILD_SHARED_LIBS=OFF",
+                "-DAVIF_LIBSHARPYUV=LOCAL",
+                "-DAVIF_LIBYUV=LOCAL",
+                "-DAVIF_CODEC_AOM=LOCAL",
+                "-DCONFIG_AV1_HIGHBITDEPTH=0",
+                "-DAVIF_CODEC_AOM_DECODE=OFF",
+                "-DAVIF_CODEC_DAV1D=LOCAL",
+                "-DCMAKE_INTERPROCEDURAL_OPTIMIZATION=ON",
+                build_type="MinSizeRel",
+            ),
+            cmd_xcopy("include", "{inc_dir}"),
+        ],
+        "libs": ["avif.lib"],
+    },
 }
 
 
@@ -500,8 +523,8 @@ def extract_dep(url: str, filename: str, prefs: dict[str, str]) -> None:
                     msg = "Attempted Path Traversal in Zip File"
                     raise RuntimeError(msg)
             zf.extractall(sources_dir)
-    elif filename.endswith((".tar.gz", ".tgz")):
-        with tarfile.open(file, "r:gz") as tgz:
+    elif filename.endswith((".tar.gz", ".tar.xz")):
+        with tarfile.open(file, "r:xz" if filename.endswith(".xz") else "r:gz") as tgz:
             for member in tgz.getnames():
                 member_abspath = os.path.abspath(os.path.join(sources_dir, member))
                 member_prefix = os.path.commonpath([sources_dir_abs, member_abspath])
@@ -692,6 +715,11 @@ def main() -> None:
         action="store_true",
         help="skip LGPL-licensed optional dependency FriBiDi",
     )
+    parser.add_argument(
+        "--no-avif",
+        action="store_true",
+        help="skip optional dependency libavif",
+    )
     args = parser.parse_args()
 
     arch_prefs = ARCHITECTURES[args.architecture]
@@ -732,6 +760,8 @@ def main() -> None:
         disabled += ["libimagequant"]
     if args.no_fribidi:
         disabled += ["fribidi"]
+    if args.no_avif or args.architecture == "ARM64":
+        disabled += ["libavif"]
 
     prefs = {
         "architecture": args.architecture,
@@ -755,7 +785,7 @@ def main() -> None:
 
     for k, v in DEPS.items():
         if "dir" not in v:
-            v["dir"] = re.sub(r"\.(tar\.gz|zip)", "", v["filename"])
+            v["dir"] = re.sub(r"\.(tar\.gz|tar\.xz|zip)", "", v["filename"])
         prefs[f"dir_{k}"] = os.path.join(sources_dir, v["dir"])
 
     print()
